@@ -3,7 +3,7 @@
  * Copyright (C) 2007, 2008 Alp Toker <alp@atoker.com>
  * Copyright (C) 2008 Collabora Ltd.
  * Copyright (C) 2011, 2017 Igalia S.L.
- * Portions Copyright (c) 2011 Motorola Mobility, Inc.  All rights reserved.
+ * Portions Copyright (c) 2011 Motorola Mobility, Inc. All rights reserved.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -60,9 +60,6 @@
 #include <wpe/WebKitColor.h>
 #include <wpe/WebKitRectangle.h>
 #include <wpe/WebKitWebViewBackend.h>
-#if (defined(ENABLE_WPE_PLATFORM) && ENABLE_WPE_PLATFORM)
-#include <wpe/wpe-platform.h>
-#endif
 
 G_BEGIN_DECLS
 
@@ -339,16 +336,6 @@ webkit_web_view_new                                  (WebKitWebViewBackend
 WEBKIT_API WebKitWebViewBackend *
 webkit_web_view_get_backend                          (WebKitWebView             *web_view);
 
-#if (defined(ENABLE_WPE_PLATFORM) && ENABLE_WPE_PLATFORM)
-WEBKIT_API WPEDisplay *
-webkit_web_view_get_display                          (WebKitWebView             *web_view);
-
-WEBKIT_API WPEView *
-webkit_web_view_get_wpe_view                         (WebKitWebView             *web_view);
-
-WEBKIT_API void
-webkit_web_view_toggle_inspector                     (WebKitWebView             *web_view);
-#endif
 
 
 WEBKIT_API gboolean
@@ -667,6 +654,11 @@ webkit_web_view_get_web_extension_mode               (WebKitWebView
 WEBKIT_API const gchar*
 webkit_web_view_get_default_content_security_policy  (WebKitWebView             *web_view);
 
+WEBKIT_API gboolean
+webkit_web_view_get_theme_color                      (WebKitWebView             *web_view,
+                                                      WebKitColor               *color);
+
+
 /**
  * webkit_web_view_run_async_javascript_function_in_world: (finish-func webkit_web_view_run_javascript_in_world_finish)
  * @web_view: a #WebKitWebView
